@@ -10,8 +10,9 @@ import logging
 import re
 import time
 
-from .utils import flatten, reload_on_change
-from ..source.base import DataSource, NoEntry
+from ..source.base import DataSource, NoEntry, DataSourceBase
+from .utils import reload_on_change
+
 logger = logging.getLogger('intake')
 
 
@@ -275,6 +276,11 @@ class Catalog(DataSource):
             kw = entry._captured_init_kwargs.copy()
             kw.pop('catalog', None)
             kw['parameters'] = {k.name: k.__getstate__()['kwargs'] for k in kw.get('parameters', [])}
+            try:
+                if issubclass(kw['driver'], DataSourceBase):
+                    kw['driver'] = ".".join([kw['driver'].__module__, kw['driver'].__name__])
+            except TypeError:
+                pass # ignore exception for a string input
             output["sources"][key] = kw
         return yaml.dump(output)
 
@@ -342,8 +348,8 @@ class Catalog(DataSource):
             # Fall back to __getitem__.
             try:
                 return self[item]  # triggers reload_on_change
-            except KeyError:
-                raise AttributeError(item)
+            except KeyError as e:
+                raise AttributeError(item) from e
         raise AttributeError(item)
 
     def __setitem__(self, key, entry):
@@ -412,7 +418,7 @@ class Catalog(DataSource):
         elif isinstance(key, tuple):
             out = self
             for part in key:
-                out = self[part]
+                out = out[part]
             return out()
         raise KeyError(key)
 
